import { LitElement, css, html } from 'lit';
import { customElement, property } from 'lit/decorators.js';
import { map } from 'lit/directives/map.js';

import '@components/AppIcon';

@customElement('arx-app-grid')
export class AppGrid extends LitElement {
  @property()
  apps: {
    icon: string | undefined;
    color: string;
    href: string;
    name: string;
  }[] = [];

  static override styles = [
    css`
      :host {
        display: grid;
        grid-template-columns: 80px;
        justify-content: space-around;
        gap: 20px;
        padding: 30px;
        margin-top: 10px;

        @media (min-width: 500px) {
          grid-template-columns: repeat(2, 80px);
        }

        @media (min-width: 768px) {
          grid-template-columns: repeat(3, 80px);
        }

        @media (min-width: 1024px) {
          grid-template-columns: repeat(4, 80px);
        }
      }
    `,
  ];

  override render() {
    return html`
      ${map(
        this.apps,
        (app) => html`
          <arx-app-icon
            .icon=${app.icon}
            .color=${app.color}
            .href=${app.href}
            .name=${app.name}
          ></arx-app-icon>
        `,
      )}
    `;
  }
}
